Learn R Programming

sdrt (version 1.0.0)

lynx: Canadian Lynx Data.

Description

Annual record of the number of the Canadian Lynx `trapped' in the Mackenzie River district of the North-West Canada for the period 1821-1934.

Usage

data(lynx)

Arguments

Format

A data list with 114 rows containing the count of Canadian Lynx from 1821-1934.