Learn R Programming

sdrt (version 1.0.0)

pd.boots: Select the model parameters using Fourier transformation method.

Description

`pd.boots()' estimates the number of lags in the model and the dimension of the time series central mean subspace.

Usage

pd.boots(y, p_list=seq(2,6,by=1), w1=0.1,  space = "mean",std = FALSE,
                                     density = "kernel", method = "FM", B=50)

Value

The output is a p-by-p matrix, estimated p and d.

dis_dp

The average block bootsrap distances.

p_hat

The estimator for p.

d_hat

The estimator for d.

Arguments

y

A univariate time series observations.

p_list

(default {2,3,4,5,6}). The candidate list of the number of lags, p.

w1

(default 0.1). The tuning parameter of the estimation.

space

(default ``mean''). Specify the SDR subspace needed to be estimated.

std

(default FALSE). If TRUE, then standardizing the time series observations.

density

(default ``kernel''). Density function for the estimation (``kernel'' or ``normal'').

method

(default ``FM''). Estimation method (``FM'' or ``NW'').

B

(default 50). Number of block bootstrap sample.

References

Samadi S. Y. and De Alwis T. P. (2023). Fourier Method of Estimating Time Series Central Mean Subspace. https://arxiv.org/pdf/2312.02110.

Examples

Run this code
# \donttest{
data("lynx")
y <- log10(lynx)
p_list=seq(2,5,by=1)
fit.model=pd.boots(y,p_list,w1=0.1,B=10)
fit.model$dis_pd
fit.model$p_hat
fit.model$d_hat
# }

Run the code above in your browser using DataLab