Learn R Programming

sdrt (version 1.0.0)

sigma_u: The tuning parameter for the estimation of the time series central mean subspace

Description

`sigma_u()' estimates the turning parameter needed to estimate time series central mean subspace in Fourier Method.

Usage

sigma_u(y, p, d, w1_list=seq(0.1,0.5,by=0.1),space="mean",
                                 std=FALSE,density="kernel",method="FM",B=20)

Value

The output is a length(sw2_seq) dimensional vector.

dis_sw2

The average block boostrap distances for each candidate list of values.

Arguments

y

A univariate time series observations.

p

Integer value. The lag of the time series.

d

Integer value. The dimension of the time series central mean subspace.

w1_list

(default {0.1, 0.2,0.3,0.4,0.5}). The sequence of candidate list for the tuning parameter.

space

(default ``mean''). Specify the SDR subspace needed to be estimated.

std

(default FALSE). If TRUE, then standardizing the time series observations.

density

(default ``kernel''). Specify the density function for the estimation (``kernel'' or ``normal'').

method

(default ``FM''). Specify the estimation method. (``FM'' or ``NW'').

B

(default 20). Number of block bootstrap samples.

References

Samadi S. Y. and De Alwis T. P. (2023). Fourier Method of Estimating Time Series Central Mean Subspace. https://arxiv.org/pdf/2312.02110.

Examples

Run this code
# \donttest{
data("lynx")
y <- log10(lynx)
p <- 3
d <- 1
w1_list=seq(0.1,0.5,by=0.1)
Tuning.model=sigma_u(y, p, d, w1_list=w1_list, std=FALSE, B=10)
Tuning.model$sigma_u_hat
# }

Run the code above in your browser using DataLab