powered by
`pd.boots()' estimates the number of lags in the model and the dimension of the time series central mean subspace.
pd.boots(y, p_list=seq(2,6,by=1), w1=0.1, space = "mean",std = FALSE, density = "kernel", method = "FM", B=50)
The output is a p-by-p matrix, estimated p and d.
The average block bootsrap distances.
The estimator for p.
The estimator for d.
A univariate time series observations.
(default {2,3,4,5,6}). The candidate list of the number of lags, p.
(default 0.1). The tuning parameter of the estimation.
(default ``mean''). Specify the SDR subspace needed to be estimated.
(default FALSE). If TRUE, then standardizing the time series observations.
(default ``kernel''). Density function for the estimation (``kernel'' or ``normal'').
(default ``FM''). Estimation method (``FM'' or ``NW'').
(default 50). Number of block bootstrap sample.
Samadi S. Y. and De Alwis T. P. (2023). Fourier Method of Estimating Time Series Central Mean Subspace. https://arxiv.org/pdf/2312.02110.
# \donttest{ data("lynx") y <- log10(lynx) p_list=seq(2,5,by=1) fit.model=pd.boots(y,p_list,w1=0.1,B=10) fit.model$dis_pd fit.model$p_hat fit.model$d_hat # }
Run the code above in your browser using DataLab