powered by
`sigma_u()' estimates the turning parameter needed to estimate time series central mean subspace in Fourier Method.
sigma_u(y, p, d, w1_list=seq(0.1,0.5,by=0.1),space="mean", std=FALSE,density="kernel",method="FM",B=20)
The output is a length(sw2_seq) dimensional vector.
The average block boostrap distances for each candidate list of values.
A univariate time series observations.
Integer value. The lag of the time series.
Integer value. The dimension of the time series central mean subspace.
(default {0.1, 0.2,0.3,0.4,0.5}). The sequence of candidate list for the tuning parameter.
(default ``mean''). Specify the SDR subspace needed to be estimated.
(default FALSE). If TRUE, then standardizing the time series observations.
(default ``kernel''). Specify the density function for the estimation (``kernel'' or ``normal'').
(default ``FM''). Specify the estimation method. (``FM'' or ``NW'').
(default 20). Number of block bootstrap samples.
Samadi S. Y. and De Alwis T. P. (2023). Fourier Method of Estimating Time Series Central Mean Subspace. https://arxiv.org/pdf/2312.02110.
# \donttest{ data("lynx") y <- log10(lynx) p <- 3 d <- 1 w1_list=seq(0.1,0.5,by=0.1) Tuning.model=sigma_u(y, p, d, w1_list=w1_list, std=FALSE, B=10) Tuning.model$sigma_u_hat # }
Run the code above in your browser using DataLab